@@ -11,7 +11,7 @@ import humanize
 import requests
 from pydantic import SecretStr, RootModel, Field, model_validator, ValidationError
 
-from oceanum.cli.common.symbols import spin, chk, err, wrn, watch, globe
+from oceanum.cli.symbols import spin, chk, err, wrn, watch, globe
 from . import models
 from .utils import format_route_status as _frs
 
@@ -251,7 +251,6 @@ class PRAXClient:
     def _check_routes(self, **params):
         project = self.get_project(**params)
         if isinstance(project, models.ProjectDetailsSchema):
-            project_name = project.name if project else 'unknown'
             for stage in project.stages:
                 for route in stage.resources.routes:
                     urls = [f"https://{d}" for d in route.custom_domains] + [route.url]
@@ -364,7 +363,7 @@ class PRAXClient:
         self._deploy_start_time = time.time()
         committed = self._wait_project_commit(**params)
         if committed:
-            started_updating = self._wait_stages_start_updating(**params)
+            self._wait_stages_start_updating(**params)
             build_succeeded = self._wait_builds_to_finish(**params)
             if build_succeeded:
                 self._wait_stages_finish_updating(**params)
@@ -441,8 +440,6 @@ class PRAXClient:
         return obj if isinstance(obj, models.SecretSpec) else errs or secret_err
 
 
-
-
     def list_sources(self, **filters) -> list[models.SourceSchema] | models.ErrorResponse:
         obj, errs = self._request('GET', 'sources', params=filters or None, schema=models.SourceSchema)
         list_sources_err = models.ErrorResponse(detail="Failed to list sources!")
@@ -482,6 +479,10 @@ class PRAXClient:
         retry_task_run_err = models.ErrorResponse(detail=f"Failed to retry task run '{run_name}'!")
         return obj if isinstance(obj, models.StagedRunSchema) else errs or retry_task_run_err
 
+    def delete_task_run(self, run_name: str, **filters) -> str | models.ErrorResponse:
+        _, errs = self._request('DELETE', f'task-runs/{run_name}', params=filters or None)
+        return errs if errs else "Task run deleted successfully!"
+    
     def list_pipelines(self, **filters) -> list[models.PipelineSchema] | models.ErrorResponse:
         obj, errs = self._request('GET', 'pipelines', params=filters or None, schema=models.PipelineSchema)
         list_pipelines_err = models.ErrorResponse(detail="Failed to list pipelines!")
@@ -526,6 +527,10 @@ class PRAXClient:
         retry_pipeline_run_err = models.ErrorResponse(detail=f"Failed to retry pipeline run '{run_name}'!")
         return obj if isinstance(obj, models.StagedRunSchema) else errs or retry_pipeline_run_err
     
+    def delete_pipeline_run(self, run_name: str, **filters) -> str | models.ErrorResponse:
+        _, errs = self._request('DELETE', f'pipeline-runs/{run_name}', params=filters or None)
+        return errs if errs else "Pipeline run deleted successfully!"
+
     def list_builds(self, **filters) -> list[models.BuildSchema] | models.ErrorResponse:
         obj, errs = self._request('GET', 'builds', params=filters or None, schema=models.BuildSchema)
         list_builds_err = models.ErrorResponse(detail="Failed to list builds!")
@@ -563,6 +568,10 @@ class PRAXClient:
         retry_build_run_err = models.ErrorResponse(detail=f"Failed to retry build run '{run_name}'!")
         return obj if isinstance(obj, models.StagedRunSchema) else errs or retry_build_run_err
     
+    def delete_build_run(self, run_name: str, **filters) -> str | models.ErrorResponse:
+        _, errs = self._request('DELETE', f'build-runs/{run_name}', params=filters or None)
+        return errs if errs else "Build run deleted successfully!"
+    
     def list_routes(self, **filters) -> list[models.RouteSchema] | models.ErrorResponse:
         obj, errs = self._request('GET', 'routes', params=filters or None, 
                                   schema=models.RouteSchema)
@@ -575,6 +584,43 @@ class PRAXClient:
         get_route_err = models.ErrorResponse(detail=f"Failed to get route '{route_name}'!")
         return obj if isinstance(obj, models.RouteSchema) else errs or get_route_err
     
+    def _download_artifact(self, 
+        resource_type: Literal['task','pipeline'],
+        resource_name: str,
+        artifact_name: str,
+        step_name: str|None = None,
+        output_path: str|None = None,
+        #force: bool = False,
+    ) -> bool:
+        if resource_type == 'pipeline' and 'step_name' is None:
+            click.echo(f" {err} 'step_name' is required to download artifact from pipeline runs!")
+            return False
+        elif resource_type == 'pipeline' and step_name is not None:
+            url = f'pipeline-runs/{resource_name}/artifacts/{step_name}/{artifact_name}'
+        else:
+            url = f'task-runs/{resource_name}/artifacts/{artifact_name}'
+        if output_path is not None:
+            output_dir = Path(output_path).parent
+            output_file = Path(output_path).name
+            artifact_path = output_dir / output_file
+        else:
+            output_dir = Path(os.getcwd())
+            output_file = f'{artifact_name}.gz'
+            artifact_path = output_dir / output_file
+        click.echo(f" {spin} Downloading artifact '{artifact_name}' from {resource_type.title()}-Run '{resource_name}' to '{output_file}' file...")
+        response, errs = self._request('GET', url, schema=None, stream=True)
+        if errs:
+            click.echo(f" {err} Failed to download artifact '{artifact_name}' from {resource_type} '{resource_name}'!")
+            click.echo(f" {wrn} {errs.detail}")
+            return False
+        elif isinstance(response, requests.Response) and response.ok:
+            with open(artifact_path, 'w+b') as f:
+                for chunk in response.raw.stream(1024, decode_content=False):
+                    f.write(chunk)
+            return True
+        click.echo(f" {err} Failed to download artifact '{artifact_name}' from {resource_type} '{resource_name}'!")
+        return False
+    
     def _get_logs(self, 
         run_name: str, 
         lines: int, 
@@ -594,6 +640,32 @@ class PRAXClient:
                 yield line
         else:
             yield errs if errs else models.ErrorResponse(detail=response.text)
+
+    def download_task_run_artifact(self, 
+        task_run_name: str, 
+        artifact_name: str, 
+        output_path: str|None = None
+    ) -> bool:
+        return self._download_artifact(
+            resource_type='task',
+            resource_name=task_run_name,
+            artifact_name=artifact_name,
+            output_path=output_path,
+        )
+
+    def download_pipeline_run_artifact(self,
+        pipeline_run_name: str, 
+        artifact_name: str, 
+        step_name: str,
+        output_path: str|None = None
+    ) -> bool:
+        return self._download_artifact(
+            resource_type='pipeline',
+            resource_name=pipeline_run_name,
+            artifact_name=artifact_name,
+            step_name=step_name,
+            output_path=output_path,
+        )
     
     def get_build_run_logs(self, run_name: str, lines: int, follow: bool, **filters) -> Iterable[str|models.ErrorResponse]:
         yield from self._get_logs(
@@ -630,8 +702,7 @@ class PRAXClient:
             endpoint='routes', 
             **filters
         )
-        
-    
+            
     def update_route_thumbnail(self, route_name: str, thumbnail: click.File) -> models.RouteSchema | models.ErrorResponse:
         files = {'thumbnail': thumbnail}
         obj, errs = self._request('POST',f'routes/{route_name}/thumbnail', files=files, schema=models.RouteSchema)
