@@ -1,5 +1,4 @@
-
-from oceanum.cli.main import main
+from oceanum.cli import main
 
 @main.group(name='prax', help='Oceanum PRAX Projects Management')
 def prax():
@@ -51,4 +50,8 @@ def allow():
 
 @prax.group(name='logs',help='View container logs')
 def logs():
+    pass
+
+@prax.group(name='download', help='Download artifacts')
+def download():
     pass
\ No newline at end of file
