@@ -2,18 +2,18 @@ import sys
 import time
 import click
 
-from oceanum.cli.common.renderer import Renderer, output_format_option, RenderField
+from oceanum.cli.renderer import Renderer, output_format_option, RenderField
 from oceanum.cli.auth import login_required
-from oceanum.cli.common.symbols import chk, err, spin, wrn
-from oceanum.cli.common.utils import format_dt
+from oceanum.cli.symbols import chk, err, spin, wrn
+from oceanum.cli.utils import format_dt
 
 from . import models
-from .main import list_group, describe, submit, terminate, retry, logs
+from .main import list_group, describe, submit, terminate, retry, logs, delete, download
 from .client import PRAXClient
 from .project import (
-    project_org_option, 
-    project_user_option, 
-    project_stage_option, 
+    project_org_option,
+    project_user_option,
+    project_stage_option,
     project_name_option,
     name_argument
 )
@@ -34,20 +34,20 @@ LIST_FIELDS = [
     RenderField(label='Stage', path='$.stage'),
     RenderField(label='Org.', path='$.org'),
     RenderField(
-        label='Last Run', 
-        path='$.last_run', 
+        label='Last Run',
+        path='$.last_run',
         mod=lambda x: frs(x['status']) if x is not None else 'N/A'
     ),
     RenderField(
-        label='Started at', 
-        path='$.last_run', 
+        label='Started at',
+        path='$.last_run',
         mod=lambda x: x['started_at'] if x is not None else 'N/A'
     ),
 ]
 
 @list_group.command(name='pipelines', help='List PRAX Pipelines')
 @click.pass_context
-@click.option('--search', help='Search by names or description', 
+@click.option('--search', help='Search by names or description',
               default=None, type=str)
 @project_org_option
 @project_user_option
@@ -64,10 +64,10 @@ def list_pipelines(ctx: click.Context, output: str, **filters):
             return [f"{icon} {x[1]}"]
         else:
             return ['N/A']
-        
+
     extra_fields = [
         RenderField(
-            label='Schedule', 
+            label='Schedule',
             path='$.["suspended", "schedule"]',
             lmod=format_schedule,
             sep=' '
@@ -81,13 +81,13 @@ def list_pipelines(ctx: click.Context, output: str, **filters):
         sys.exit(1)
     else:
         click.echo(Renderer(
-            data=pipelines, 
+            data=pipelines,
             fields=LIST_FIELDS+extra_fields
         ).render(output_format=output))
 
 @list_group.command(name='tasks', help='List all PRAX Tasks')
 @click.pass_context
-@click.option('--search', help='Search by names or description', 
+@click.option('--search', help='Search by names or description',
               default=None, type=str)
 @project_org_option
 @project_user_option
@@ -135,28 +135,28 @@ def describe_task(ctx: click.Context, name: str, **filters):
     ]
     if isinstance(task, models.TaskSchema):
         click.echo(Renderer(
-            data=[task], 
+            data=[task],
             fields=task_fields
         ).render(output_format='table', tablefmt='plain'))
         if task.last_run:
             click.echo("Last Run:")
             click.echo(Renderer(
-                data=[task.last_run], 
-                fields=run_fields, 
+                data=[task.last_run],
+                fields=run_fields,
                 indent=2
             ).render(output_format='table', tablefmt='plain'))
             if task.last_run.arguments:
                 click.echo("    Arguments:")
                 click.echo(Renderer(
-                    data=[task.last_run.arguments], 
-                    fields=[], 
+                    data=[task.last_run.arguments],
+                    fields=[],
                     indent=4
                 ).render(output_format='yaml'))
             if task.last_run.details:
                 click.echo("  Run Details:")
                 click.echo(Renderer(
-                    data=[task.last_run.details], 
-                    fields=[], 
+                    data=[task.last_run.details],
+                    fields=[],
                     indent=2
                 ).render(output_format='yaml'))
     else:
@@ -176,7 +176,7 @@ def describe_task(ctx: click.Context, name: str, **filters):
 def submit_task(ctx: click.Context, name: str, parameter: list[str]|None, **filters):
     client = PRAXClient(ctx)
     task = client.get_task(name, **filters)
-    
+
     if isinstance(task, models.ErrorResponse):
         click.echo(f" {err} Error fetching task:")
         echoerr(task)
@@ -202,7 +202,7 @@ def submit_task(ctx: click.Context, name: str, parameter: list[str]|None, **filt
 def terminate_task(ctx: click.Context, name: str, **filters):
     client = PRAXClient(ctx)
     task = client.get_task_run(name)
-    
+
     if isinstance(task, models.ErrorResponse):
         click.echo(f" {err} Error fetching task:")
         echoerr(task)
@@ -266,23 +266,84 @@ def retry_task(ctx: click.Context, name: str, **filters):
 def get_task_logs(ctx: click.Context, name: str, lines: int, follow: bool, **filters):
     client = PRAXClient(ctx)
     task = client.get_task(name, **filters)
-    if isinstance(task, models.ErrorResponse):
-        click.echo(f" {err} Error fetching task:")
-        echoerr(task)
-        sys.exit(1)
-    if task.last_run is None:
-        click.echo(f" {err} No active runs found for task '{name}'!")
-        sys.exit(1)
-
-    latest_run = task.last_run
-    click.echo(f"Fetching logs for task run: {latest_run.name} ...")
-    for line in client.get_task_run_logs(latest_run.name, lines, follow):
+    if isinstance(task, models.TaskSchema):
+        task_run = task.last_run
+    else:
+        task_run = client.get_task_run(name)
+        if isinstance(task_run, models.ErrorResponse):
+            click.echo(f" {err} Error fetching Task:")
+            echoerr(task_run)
+            sys.exit(1)
+    
+    click.echo(f"Fetching logs for Task-Run: {task_run.name} ...")
+    for line in client.get_task_run_logs(task_run.name, lines, follow):
         if isinstance(line, models.ErrorResponse):
             click.echo(f" {err} Error fetching logs:")
             echoerr(line)
             sys.exit(1)
         click.echo(line)
 
+@download.command(name='task-artifact', help='Download PRAX Task output Artifact')
+@click.pass_context
+@name_argument
+@project_org_option
+@project_user_option
+@project_name_option
+@project_stage_option
+@click.option('-a','--artifact-name', help='Name of the artifact to download', required=True, type=str)
+@click.option('-o','--output', help='Output path to save the artifact (a .gz file)', default=None, type=str)
+@login_required
+def download_task_artifact(
+    ctx: click.Context,
+    name: str,
+    artifact_name: str,
+    output: str|None,
+    **filters
+):
+    client = PRAXClient(ctx)
+    task = client.get_task(name, **filters)
+
+    if isinstance(task, models.TaskSchema):
+        task_run = task.last_run
+    else:
+        task_run = client.get_task_run(name)
+    if task_run is None:
+        click.echo(f" {err} No task run found for task: {name}")
+        sys.exit(1)
+    
+    if isinstance(task_run, models.ErrorResponse):
+        click.echo(f" {err} Error fetching task run:")
+        echoerr(task_run)
+        sys.exit(1)
+    
+    if client.download_task_run_artifact(task_run.name, artifact_name, output):
+        click.echo(f" {chk} Artifact '{artifact_name}' downloaded successfully!")
+
+
+@delete.command(name='task', help='Delete PRAX Task')
+@click.pass_context
+@name_argument
+@project_org_option
+@project_user_option
+@project_name_option
+@project_stage_option
+@login_required
+def delete_task(ctx: click.Context, name: str, **filters):
+    client = PRAXClient(ctx)
+    task = client.get_task_run(name)
+    if isinstance(task, models.ErrorResponse):
+        click.echo(f" {err} Error fetching task:")
+        echoerr(task)
+        sys.exit(1)
+    else:
+        resp = client.delete_task_run(name, **filters)
+        if isinstance(resp, models.ErrorResponse):
+            click.echo(f" {err} Error deleting task:")
+            echoerr(resp)
+            sys.exit(1)
+        else:
+            click.echo(f"{chk} Task deleted successfully!")
+
 
 @list_group.command(name='builds', help='List all PRAX Builds')
 @click.pass_context
@@ -343,28 +404,28 @@ def describe_build(ctx: click.Context, name: str, **filters):
     ]
     if isinstance(build, models.BuildSchema):
         click.echo(Renderer(
-            data=[build], 
+            data=[build],
             fields=build_fields
         ).render(output_format='table', tablefmt='plain'))
         if build.last_run:
             click.echo("Last Run:")
             click.echo(Renderer(
-                data=[build.last_run], 
-                fields=run_fields, 
+                data=[build.last_run],
+                fields=run_fields,
                 indent=2
             ).render(output_format='table', tablefmt='plain'))
             if build.last_run.arguments:
                 click.echo("    Arguments:")
                 click.echo(Renderer(
-                    data=[build.last_run.arguments], 
-                    fields=[], 
+                    data=[build.last_run.arguments],
+                    fields=[],
                     indent=4
                 ).render(output_format='yaml'))
             if build.last_run.details:
                 click.echo("  Run Details:")
                 click.echo(Renderer(
-                    data=[build.last_run.details], 
-                    fields=[], 
+                    data=[build.last_run.details],
+                    fields=[],
                     indent=2
                 ).render(output_format='yaml'))
     else:
@@ -459,23 +520,45 @@ def retry_build(ctx: click.Context, name: str, **filters):
 def get_build_logs(ctx: click.Context, name: str, lines: int, follow: bool, **filters):
     client = PRAXClient(ctx)
     build = client.get_build(name, **filters)
-    if isinstance(build, models.ErrorResponse):
-        click.echo(f" {err} Error fetching build:")
-        echoerr(build)
-        sys.exit(1)
-    if build.last_run is None:
-        click.echo(f" {err} No active runs found for build '{name}'!")
-        sys.exit(1)
-
-    latest_run = build.last_run
-    click.echo(f"Fetching logs for build run: {latest_run.name} ...")
-    for line in client.get_build_run_logs(latest_run.name, lines, follow):
+    if isinstance(build, models.BuildSchema):
+        build_run = build.last_run
+    else:
+        build_run = client.get_build_run(name)
+        if isinstance(build_run, models.ErrorResponse):
+            click.echo(f" {err} Error fetching build:")
+            echoerr(build_run)
+            sys.exit(1)
+    click.echo(f"Fetching logs for Build-Run: {build_run.name} ...")
+    for line in client.get_build_run_logs(build_run.name, lines, follow):
         if isinstance(line, models.ErrorResponse):
             click.echo(f" {err} Error fetching logs:")
             echoerr(line)
             sys.exit(1)
         click.echo(line)
 
+@delete.command(name='build', help='Delete PRAX Build')
+@click.pass_context
+@name_argument
+@project_org_option
+@project_user_option
+@project_name_option
+@project_stage_option
+@login_required
+def delete_build(ctx: click.Context, name: str, **filters):
+    client = PRAXClient(ctx)
+    build = client.get_build_run(name)
+    if isinstance(build, models.ErrorResponse):
+        click.echo(f" {err} Error fetching build:")
+        echoerr(build)
+        sys.exit(1)
+    else:
+        resp = client.delete_build_run(name, **filters)
+        if isinstance(resp, models.ErrorResponse):
+            click.echo(f" {err} Error deleting build:")
+            echoerr(resp)
+            sys.exit(1)
+        else:
+            click.echo(f"{chk} Build deleted successfully!")
 
 @describe.command(name='pipeline', help='Describe PRAX Pipeline')
 @click.pass_context
@@ -507,7 +590,7 @@ def describe_pipeline(ctx: click.Context, name: str, **filters):
     ]
     if isinstance(pipeline, models.PipelineSchema):
         click.echo(Renderer(
-            data=[pipeline], 
+            data=[pipeline],
             fields=pipeline_fields
         ).render(output_format='table', tablefmt='plain'))
         # if pipeline.details:
@@ -519,22 +602,22 @@ def describe_pipeline(ctx: click.Context, name: str, **filters):
         if pipeline.last_run:
             click.echo("Last Run:")
             click.echo(Renderer(
-                data=[pipeline.last_run], 
-                fields=run_fields, 
+                data=[pipeline.last_run],
+                fields=run_fields,
                 indent=2
             ).render(output_format='table', tablefmt='plain'))
             if pipeline.last_run.arguments:
                 click.echo("    Arguments:")
                 click.echo(Renderer(
-                    data=[pipeline.last_run.arguments], 
-                    fields=[], 
+                    data=[pipeline.last_run.arguments],
+                    fields=[],
                     indent=4
                 ).render(output_format='yaml'))
             if pipeline.last_run.details:
                 click.echo("  Run Details:")
                 click.echo(Renderer(
-                    data=[pipeline.last_run.details], 
-                    fields=[], 
+                    data=[pipeline.last_run.details],
+                    fields=[],
                     indent=2
                 ).render(output_format='yaml'))
 
@@ -631,23 +714,90 @@ def retry_pipeline(ctx: click.Context, name: str, **filters):
 def get_pipeline_logs(ctx: click.Context, name: str, lines: int, follow: bool, **filters):
     client = PRAXClient(ctx)
     pipeline = client.get_pipeline(name, **filters)
-    if isinstance(pipeline, models.ErrorResponse):
-        click.echo(f" {err} Error fetching pipeline:")
-        echoerr(pipeline)
-        sys.exit(1)
-    if pipeline.last_run is None:
-        click.echo(f" {err} No active runs found for pipeline '{name}'!")
-        sys.exit(1)
-
-    latest_run = pipeline.last_run
-    click.echo(f"Fetching logs for pipeline run: {latest_run.name} ...")
-    for line in client.get_pipeline_run_logs(latest_run.name, lines, follow, **filters):
+    if isinstance(pipeline, models.PipelineSchema):
+        pipeline_run = pipeline.last_run
+    else:
+        pipeline_run = client.get_pipeline_run(name)
+        if isinstance(pipeline_run, models.ErrorResponse):
+            click.echo(f" {err} Error fetching Pipeline:")
+            echoerr(pipeline_run)
+            sys.exit(1)
+    click.echo(f"Fetching logs for Pipeline-Run: {pipeline_run.name} ...")
+    for line in client.get_pipeline_run_logs(pipeline_run.name, lines, follow, **filters):
         if isinstance(line, models.ErrorResponse):
             click.echo(f" {err} Error fetching logs:")
             echoerr(line)
             sys.exit(1)
         click.echo(line)
 
+@download.command(name='pipeline-artifact', help='Download PRAX Pipeline Step output Artifact')
+@click.pass_context
+@name_argument
+@project_org_option
+@project_user_option
+@project_name_option
+@project_stage_option
+@click.option('-a','--artifact-name', help='Name of the artifact to download', required=True, type=str)
+@click.option('-s','--step-name', help='Name of the pipeline step which produced the artifact', required=True, type=str)
+@click.option('-o','--output', help='Output path to save the artifact (a .gz file)', default=None, type=str)
+@login_required
+def download_pipeline_artifact(
+    ctx: click.Context,
+    name: str,
+    artifact_name: str,
+    step_name: str,
+    output: str|None = None,
+    **filters
+):
+    client = PRAXClient(ctx)
+    pipeline = client.get_pipeline(name, **filters)
+    if isinstance(pipeline, models.PipelineSchema):
+        pipeline_run = pipeline.last_run
+    else:
+        pipeline_run = client.get_pipeline_run(name, **filters)
+    
+    if pipeline_run is None:
+        click.echo(f" {err} No pipeline run found for pipeline: {name}")
+        sys.exit(1)
+    
+    if isinstance(pipeline_run, models.ErrorResponse):
+        click.echo(f" {err} Error fetching pipeline run:")
+        echoerr(pipeline_run)
+        sys.exit(1)
+    
+    if client.download_pipeline_run_artifact(
+        pipeline_run.name, 
+        artifact_name,
+        step_name,
+        output
+    ):
+        click.echo(f" {chk} Artifact '{artifact_name}' from step '{step_name}' downloaded successfully!")
+
+
+@delete.command(name='pipeline', help='Delete PRAX Pipeline')
+@click.pass_context
+@name_argument
+@project_org_option
+@project_user_option
+@project_name_option
+@project_stage_option
+@login_required
+def delete_pipeline(ctx: click.Context, name: str, **filters):
+    client = PRAXClient(ctx)
+    pipeline = client.get_pipeline_run(name, **filters)
+    if isinstance(pipeline, models.ErrorResponse):
+        click.echo(f" {err} Error fetching pipeline:")
+        echoerr(pipeline)
+        sys.exit(1)
+    else:
+        resp = client.delete_pipeline_run(name, **filters)
+        if isinstance(resp, models.ErrorResponse):
+            click.echo(f" {err} Error deleting pipeline:")
+            echoerr(resp)
+            sys.exit(1)
+        else:
+            click.echo(f"{chk} Pipeline deleted successfully!")
+
 # @stop.command(name='pipeline', help='Stop PRAX Pipeline')
 # @click.pass_context
 # @name_argument
